#
# spec file for package python-pyforgejo
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyforgejo
Version:        2.0.4
Release:        1.1
Summary:        A client library for accessing the Forgejo API
License:        MIT
URL:            https://codeberg.org/harabat/pyforgejo
Source0:        https://files.pythonhosted.org/packages/source/p/pyforgejo/pyforgejo-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module httpx >= 0.20}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 2.0.0}
BuildRequires:  %{python_module pydantic >= 2.11.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dotenv >= 1.1.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-annotated-types >= 0.6.0
Requires:       python-anyio
Requires:       python-attrs
Requires:       python-certifi
Requires:       python-click >= 5.0
Requires:       python-colorama
Requires:       python-exceptiongroup
Requires:       python-h11
Requires:       python-httpcore
Requires:       python-httpx
Requires:       python-idna
Requires:       python-iniconfig
Requires:       python-packaging
Requires:       python-pluggy
Requires:       python-pydantic
Requires:       python-pydantic-core
Requires:       python-python-dateutil
Requires:       python-python-dotenv
Requires:       python-sniffio
Requires:       python-tomli
Requires:       python-typing-extensions >= 4.12.2
%python_subpackages

%description
A client library for accessing the Forgejo API.
%{name} was generated with the help of openapi-python-client, and doesn't
try to be compatible with gitea.

%prep
%autosetup -p1 -n pyforgejo-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
#tests need internet

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pyforgejo
%{python_sitelib}/pyforgejo-%{version}.dist-info

%changelog
* Thu May  8 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0.4:
  * update pyproject.toml
  * update dev steps
  * remove debug statements for base_url and api_key
  * update dev steps
* Tue Apr 29 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0.3:
  * update pyproject.toml
  * update readme
  * update header
  * update authorization header
  * update api specs
  * update tests
* Thu Apr 17 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0.2:
  * update pyproject.toml
  * regenerate client
  * update dev dependencies
  * switch from poetry to uv
  * publish with uv to testpypi
  * format pyproject.toml
  * pyproject: remove invalid packages field
  * Add py.typed file
  * pyproject: limit to first poetry version that supports PEP 621
  * add dev dependencies
  * format tests
  * format readme
  * update poetry lock file
* Mon Apr 14 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0.1:
  * update pyproject.toml
  * regenerate client
  * format tests
  * add test for repoGetContents endpoint
  * switch from conda to uv
  * switch to OpenAPI 3 in dev
  * add API specs
  * update api resources
  * update dev steps
  * use different production and testing tokens
  * add POST tests
  * update pyproject format
  * format with ruff
  * update ruff settings
  * add tests
  * update install guidance
  * mention 1.0 branch
  * update client to Forgejo 10
  * update development guidance
  * update formatting of .env block
  * update formatting of api token in .env file
  * add lock file
  * add dev dependencies
  * update readme for 2.0
* Thu Feb  6 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0.0:
  * massive rewrite, no changelogs given (everything is in one commit)
* Sat Dec 14 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.4:
  * trip whitespace in readme
  * add advice about harabat/openapi-python-client fork for development
  * increment version and publish on pypi
  * add tests section to readme
  * add refactoring warning
* Fri Mar  8 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.0.2:
  * add activitypub endpoints following
  * add advice about harabat/openapi-python-client fork for development
  * add warning about missing parsed data and detailed methods
* Thu Feb 22 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
